@@ -45,6 +45,7 @@ my $NAME = [
 	qr/Victor (?:M|\w+[oe]v\b)/,
 	qr/Vladimir/,
 	qr/Vladislav/,
+	qr/Vyacheslav/,
 	qr/Walery/,
 	qr/Yur[iy]/,
 	qr/Zaha/,
@@ -77,7 +78,7 @@ print
 		
 		# ru
 		grep { $_->{'pause'} eq 'STEALTHY' and $_->{'author'}=0; 1}
-		grep { $_->{'pause'} !~ /^KORSHAK|AGNISLAV|ZERO|ZWON|SODASODA|CUB|DZHARIY|IHEFFNER|QUEVLAR|VTI|GUGU|EJS|GRUBER|EGORSH|MVUETS|BEROV|CYBER|NIKIP|TTOD|OMEGA|DRINCHEV|YAKWOO|PLCGI|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ$/ }
+		grep { $_->{'pause'} !~ /^(KORSHAK|AGNISLAV|ZERO|ZWON|SODASODA|CUB|DZHARIY|IHEFFNER|QUEVLAR|VTI|GUGU|EJS|GRUBER|EGORSH|MVUETS|BEROV|CYBER|NIKIP|TTOD|OMEGA|DRINCHEV|YAKWOO|PLCGI|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ)$/ }
 		
 		grep { $_->{'email'} !~ /ua$/ }
 		grep { $_->{'email'} !~ /bg$/ }
